diff -u b/core/lib/Drupal/Core/Action/ActionCollection.php b/core/lib/Drupal/Core/Action/ActionPluginCollection.php
--- b/core/lib/Drupal/Core/Action/ActionCollection.php
+++ b/core/lib/Drupal/Core/Action/ActionPluginCollection.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\Core\Action\ActionCollection.
+ * Contains \Drupal\Core\Action\ActionPluginCollection.
  */
 
 namespace Drupal\Core\Action;
@@ -12,7 +12,7 @@
 /**
  * Provides a container for lazily loading Action plugins.
  */
-class ActionCollection extends DefaultSingleLazyPluginCollection {
+class ActionPluginCollection extends DefaultSingleLazyPluginCollection {
 
   /**
    * {@inheritdoc}
diff -u b/core/lib/Drupal/Core/Block/BlockBase.php b/core/lib/Drupal/Core/Block/BlockBase.php
--- b/core/lib/Drupal/Core/Block/BlockBase.php
+++ b/core/lib/Drupal/Core/Block/BlockBase.php
@@ -13,7 +13,7 @@
 use Drupal\Component\Plugin\ContextAwarePluginInterface;
 use Drupal\Core\Access\AccessResult;
 use Drupal\Core\Condition\ConditionAccessResolverTrait;
-use Drupal\Core\Condition\ConditionLazyPluginCollection;
+use Drupal\Core\Condition\ConditionPluginCollection;
 use Drupal\Core\Form\FormState;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Plugin\ContextAwarePluginBase;
@@ -40,7 +40,7 @@
   /**
    * The condition plugin collection.
    *
-   * @var \Drupal\Core\Condition\ConditionLazyPluginCollection
+   * @var \Drupal\Core\Condition\ConditionPluginCollection
    */
   protected $conditionCollection;
 
@@ -508,7 +508,7 @@
    */
   public function getVisibilityConditions() {
     if (!isset($this->conditionCollection)) {
-      $this->conditionCollection = new ConditionLazyPluginCollection($this->conditionPluginManager(), $this->configuration['visibility']);
+      $this->conditionCollection = new ConditionPluginCollection($this->conditionPluginManager(), $this->configuration['visibility']);
     }
     return $this->conditionCollection;
   }
diff -u b/core/lib/Drupal/Core/Block/BlockPluginInterface.php b/core/lib/Drupal/Core/Block/BlockPluginInterface.php
--- b/core/lib/Drupal/Core/Block/BlockPluginInterface.php
+++ b/core/lib/Drupal/Core/Block/BlockPluginInterface.php
@@ -146,7 +146,7 @@
   /**
    * Gets conditions for this block.
    *
-   * @return \Drupal\Core\Condition\ConditionInterface[]|\Drupal\Core\Condition\ConditionLazyPluginCollection
+   * @return \Drupal\Core\Condition\ConditionInterface[]|\Drupal\Core\Condition\ConditionPluginCollection
    *   An array or collection of configured condition plugins.
    */
   public function getVisibilityConditions();
diff -u b/core/lib/Drupal/Core/Condition/ConditionLazyPluginCollection.php b/core/lib/Drupal/Core/Condition/ConditionPluginCollection.php
--- b/core/lib/Drupal/Core/Condition/ConditionLazyPluginCollection.php
+++ b/core/lib/Drupal/Core/Condition/ConditionPluginCollection.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\Core\Condition\ConditionLazyPluginCollection.
+ * Contains \Drupal\Core\Condition\ConditionPluginCollection.
  */
 
 namespace Drupal\Core\Condition;
@@ -13,7 +13,7 @@
 /**
  * Provides a collection of condition plugins.
  */
-class ConditionLazyPluginCollection extends DefaultLazyPluginCollection {
+class ConditionPluginCollection extends DefaultLazyPluginCollection {
 
   /**
    * An array of collected contexts for conditions.
diff -u b/core/modules/block/src/Event/BlockConditionContextEvent.php b/core/modules/block/src/Event/BlockConditionContextEvent.php
--- b/core/modules/block/src/Event/BlockConditionContextEvent.php
+++ b/core/modules/block/src/Event/BlockConditionContextEvent.php
@@ -7,7 +7,7 @@
 
 namespace Drupal\block\Event;
 
-use Drupal\Core\Condition\ConditionLazyPluginCollection;
+use Drupal\Core\Condition\ConditionPluginCollection;
 use Symfony\Component\EventDispatcher\Event;
 
 /**
@@ -18,14 +18,14 @@
 class BlockConditionContextEvent extends Event {
 
   /**
-   * @var \Drupal\Core\Condition\ConditionLazyPluginCollection
+   * @var \Drupal\Core\Condition\ConditionPluginCollection
    */
   protected $conditions;
 
   /**
-   * @param \Drupal\Core\Condition\ConditionLazyPluginCollection $conditions
+   * @param \Drupal\Core\Condition\ConditionPluginCollection $conditions
    */
-  public function __construct(ConditionLazyPluginCollection $conditions) {
+  public function __construct(ConditionPluginCollection $conditions) {
     $this->conditions = $conditions;
   }
 
diff -u b/core/modules/block/src/EventSubscriber/BlockConditionContextSubscriberBase.php b/core/modules/block/src/EventSubscriber/BlockConditionContextSubscriberBase.php
--- b/core/modules/block/src/EventSubscriber/BlockConditionContextSubscriberBase.php
+++ b/core/modules/block/src/EventSubscriber/BlockConditionContextSubscriberBase.php
@@ -18,7 +18,7 @@
 abstract class BlockConditionContextSubscriberBase implements EventSubscriberInterface {
 
   /**
-   * @var \Drupal\Core\Condition\ConditionLazyPluginCollection
+   * @var \Drupal\Core\Condition\ConditionPluginCollection
    */
   protected $conditions;
 
diff -u b/core/modules/editor/src/Tests/EditorFileReferenceFilterTest.php b/core/modules/editor/src/Tests/EditorFileReferenceFilterTest.php
--- b/core/modules/editor/src/Tests/EditorFileReferenceFilterTest.php
+++ b/core/modules/editor/src/Tests/EditorFileReferenceFilterTest.php
@@ -9,7 +9,7 @@
 
 use Drupal\Core\Cache\Cache;
 use Drupal\simpletest\KernelTestBase;
-use Drupal\filter\FilterCollection;
+use Drupal\filter\FilterPluginCollection;
 
 /**
  * Tests Editor module's file reference filter.
@@ -40,7 +40,7 @@
     $this->installSchema('file', array('file_usage'));
 
     $manager = $this->container->get('plugin.manager.filter');
-    $bag = new FilterCollection($manager, array());
+    $bag = new FilterPluginCollection($manager, array());
     $this->filters = $bag->getAll();
   }
 
diff -u b/core/modules/filter/src/Entity/FilterFormat.php b/core/modules/filter/src/Entity/FilterFormat.php
--- b/core/modules/filter/src/Entity/FilterFormat.php
+++ b/core/modules/filter/src/Entity/FilterFormat.php
@@ -11,7 +11,7 @@
 use Drupal\Core\Entity\EntityWithPluginCollectionInterface;
 use Drupal\Core\Entity\EntityStorageInterface;
 use Drupal\filter\FilterFormatInterface;
-use Drupal\filter\FilterCollection;
+use Drupal\filter\FilterPluginCollection;
 use Drupal\filter\Plugin\FilterInterface;
 
 /**
@@ -114,7 +114,7 @@
   /**
    * Holds the collection of filters that are attached to this format.
    *
-   * @var \Drupal\filter\FilterCollection
+   * @var \Drupal\filter\FilterPluginCollection
    */
   protected $filterCollection;
 
@@ -130,7 +130,7 @@
    */
   public function filters($instance_id = NULL) {
     if (!isset($this->filterCollection)) {
-      $this->filterCollection = new FilterCollection(\Drupal::service('plugin.manager.filter'), $this->filters);
+      $this->filterCollection = new FilterPluginCollection(\Drupal::service('plugin.manager.filter'), $this->filters);
       $this->filterCollection->sort();
     }
     if (isset($instance_id)) {
diff -u b/core/modules/filter/src/FilterCollection.php b/core/modules/filter/src/FilterPluginCollection.php
--- b/core/modules/filter/src/FilterCollection.php
+++ b/core/modules/filter/src/FilterPluginCollection.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\filter\FilterCollection.
+ * Contains \Drupal\filter\FilterPluginCollection.
  */
 
 namespace Drupal\filter;
@@ -13,7 +13,7 @@
 /**
  * A collection of filters.
  */
-class FilterCollection extends DefaultLazyPluginCollection {
+class FilterPluginCollection extends DefaultLazyPluginCollection {
 
   /**
    * All possible filter plugin IDs.
diff -u b/core/modules/filter/src/FilterFormatInterface.php b/core/modules/filter/src/FilterFormatInterface.php
--- b/core/modules/filter/src/FilterFormatInterface.php
+++ b/core/modules/filter/src/FilterFormatInterface.php
@@ -20,7 +20,7 @@
    * @param string $instance_id
    *   (optional) The ID of a filter plugin instance to return.
    *
-   * @return \Drupal\filter\FilterCollection|\Drupal\filter\Plugin\FilterInterface
+   * @return \Drupal\filter\FilterPluginCollection|\Drupal\filter\Plugin\FilterInterface
    *   Either the filter collection or a specific filter plugin instance.
    */
   public function filters($instance_id = NULL);
@@ -30,7 +30,7 @@
    *
    * Sets or replaces the configuration of a filter plugin in $this->filters,
    * and if instantiated already, also ensures that the actual filter plugin on
-   * the FilterCollection contains the identical configuration.
+   * the FilterPluginCollection contains the identical configuration.
    *
    * @param string $instance_id
    *   The ID of a filter plugin to set the configuration for.
diff -u b/core/modules/filter/src/Plugin/FilterBase.php b/core/modules/filter/src/Plugin/FilterBase.php
--- b/core/modules/filter/src/Plugin/FilterBase.php
+++ b/core/modules/filter/src/Plugin/FilterBase.php
@@ -58,7 +58,7 @@
   /**
    * A collection of all filters this filter participates in.
    *
-   * @var \Drupal\filter\FilterCollection
+   * @var \Drupal\filter\FilterPluginCollection
    */
   protected $collection;
 
diff -u b/core/modules/filter/src/Tests/FilterUnitTest.php b/core/modules/filter/src/Tests/FilterUnitTest.php
--- b/core/modules/filter/src/Tests/FilterUnitTest.php
+++ b/core/modules/filter/src/Tests/FilterUnitTest.php
@@ -10,7 +10,7 @@
 use Drupal\Component\Utility\Html;
 use Drupal\Component\Utility\String;
 use Drupal\simpletest\DrupalUnitTestBase;
-use Drupal\filter\FilterCollection;
+use Drupal\filter\FilterPluginCollection;
 
 /**
  * Tests Filter module filters individually.
@@ -36,7 +36,7 @@
     $this->installConfig(array('system'));
 
     $manager = $this->container->get('plugin.manager.filter');
-    $bag = new FilterCollection($manager, array());
+    $bag = new FilterPluginCollection($manager, array());
     $this->filters = $bag->getAll();
   }
 
diff -u b/core/modules/image/src/Entity/ImageStyle.php b/core/modules/image/src/Entity/ImageStyle.php
--- b/core/modules/image/src/Entity/ImageStyle.php
+++ b/core/modules/image/src/Entity/ImageStyle.php
@@ -14,7 +14,7 @@
 use Drupal\Core\Entity\EntityWithPluginCollectionInterface;
 use Drupal\Core\Routing\RequestHelper;
 use Drupal\Core\Site\Settings;
-use Drupal\image\ImageEffectCollection;
+use Drupal\image\ImageEffectPluginCollection;
 use Drupal\image\ImageEffectInterface;
 use Drupal\image\ImageStyleInterface;
 use Drupal\Component\Utility\Crypt;
@@ -85,7 +85,7 @@
   /**
    * Holds the collection of image effects that are used by this image style.
    *
-   * @var \Drupal\image\ImageEffectCollection
+   * @var \Drupal\image\ImageEffectPluginCollection
    */
   protected $effectsCollection;
 
@@ -347,7 +347,7 @@
    */
   public function getEffects() {
     if (!$this->effectsCollection) {
-      $this->effectsCollection = new ImageEffectCollection($this->getImageEffectPluginManager(), $this->effects);
+      $this->effectsCollection = new ImageEffectPluginCollection($this->getImageEffectPluginManager(), $this->effects);
       $this->effectsCollection->sort();
     }
     return $this->effectsCollection;
diff -u b/core/modules/image/src/ImageEffectCollection.php b/core/modules/image/src/ImageEffectPluginCollection.php
--- b/core/modules/image/src/ImageEffectCollection.php
+++ b/core/modules/image/src/ImageEffectPluginCollection.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\image\ImageEffectCollection.
+ * Contains \Drupal\image\ImageEffectPluginCollection.
  */
 
 namespace Drupal\image;
@@ -12,7 +12,7 @@
 /**
  * A collection of image effects.
  */
-class ImageEffectCollection extends DefaultLazyPluginCollection {
+class ImageEffectPluginCollection extends DefaultLazyPluginCollection {
 
   /**
    * {@inheritdoc}
diff -u b/core/modules/image/src/ImageStyleInterface.php b/core/modules/image/src/ImageStyleInterface.php
--- b/core/modules/image/src/ImageStyleInterface.php
+++ b/core/modules/image/src/ImageStyleInterface.php
@@ -157,7 +157,7 @@
   /**
    * Returns the image effects for this style.
    *
-   * @return \Drupal\image\ImageEffectCollection|\Drupal\image\ImageEffectInterface[]
+   * @return \Drupal\image\ImageEffectPluginCollection|\Drupal\image\ImageEffectInterface[]
    *   The image effect plugin collection.
    */
   public function getEffects();
diff -u b/core/modules/system/src/Entity/Action.php b/core/modules/system/src/Entity/Action.php
--- b/core/modules/system/src/Entity/Action.php
+++ b/core/modules/system/src/Entity/Action.php
@@ -11,7 +11,7 @@
 use Drupal\Core\Config\Entity\ConfigEntityInterface;
 use Drupal\Core\Entity\EntityWithPluginCollectionInterface;
 use Drupal\system\ActionConfigEntityInterface;
-use Drupal\Core\Action\ActionCollection;
+use Drupal\Core\Action\ActionPluginCollection;
 use Drupal\Component\Plugin\ConfigurablePluginInterface;
 
 /**
@@ -67,7 +67,7 @@
   /**
    * The plugin collection that stores action plugins.
    *
-   * @var \Drupal\Core\Action\ActionCollection
+   * @var \Drupal\Core\Action\ActionPluginCollection
    */
   protected $pluginCollection;
 
@@ -79,7 +79,7 @@
    */
   protected function getPluginCollection() {
     if (!$this->pluginCollection) {
-      $this->pluginCollection = new ActionCollection(\Drupal::service('plugin.manager.action'), $this->plugin, $this->configuration);
+      $this->pluginCollection = new ActionPluginCollection(\Drupal::service('plugin.manager.action'), $this->plugin, $this->configuration);
     }
     return $this->pluginCollection;
   }
diff -u b/core/modules/tour/src/Entity/Tour.php b/core/modules/tour/src/Entity/Tour.php
--- b/core/modules/tour/src/Entity/Tour.php
+++ b/core/modules/tour/src/Entity/Tour.php
@@ -9,7 +9,7 @@
 
 use Drupal\Core\Config\Entity\ConfigEntityBase;
 use Drupal\Core\Entity\EntityStorageInterface;
-use Drupal\tour\TipsCollection;
+use Drupal\tour\TipsPluginCollection;
 use Drupal\tour\TourInterface;
 
 /**
@@ -67,7 +67,7 @@
   /**
    * Holds the collection of tips that are attached to this tour.
    *
-   * @var \Drupal\tour\TipsCollection
+   * @var \Drupal\tour\TipsPluginCollection
    */
   protected $tipsCollection;
 
@@ -84,7 +84,7 @@
   public function __construct(array $values, $entity_type) {
     parent::__construct($values, $entity_type);
 
-    $this->tipsCollection = new TipsCollection(\Drupal::service('plugin.manager.tour.tip'), $this->tips);
+    $this->tipsCollection = new TipsPluginCollection(\Drupal::service('plugin.manager.tour.tip'), $this->tips);
   }
 
   /**
diff -u b/core/modules/tour/src/TipsCollection.php b/core/modules/tour/src/TipsPluginCollection.php
--- b/core/modules/tour/src/TipsCollection.php
+++ b/core/modules/tour/src/TipsPluginCollection.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\tour\TipsCollection.
+ * Contains \Drupal\tour\TipsPluginCollection.
  */
 
 namespace Drupal\tour;
@@ -12,7 +12,7 @@
 /**
  * A collection of tips.
  */
-class TipsCollection extends DefaultLazyPluginCollection {
+class TipsPluginCollection extends DefaultLazyPluginCollection {
 
   /**
    * {@inheritdoc}
diff -u b/core/modules/views/src/Tests/ViewExecutableTest.php b/core/modules/views/src/Tests/ViewExecutableTest.php
--- b/core/modules/views/src/Tests/ViewExecutableTest.php
+++ b/core/modules/views/src/Tests/ViewExecutableTest.php
@@ -10,7 +10,7 @@
 use Drupal\views\Views;
 use Drupal\views\ViewExecutable;
 use Drupal\views\ViewExecutableFactory;
-use Drupal\views\DisplayCollection;
+use Drupal\views\DisplayPluginCollection;
 use Drupal\views\Plugin\views\display\DefaultDisplay;
 use Drupal\views\Plugin\views\display\Page;
 use Drupal\views\Plugin\views\style\DefaultStyle;
@@ -196,7 +196,7 @@
 
     // Tests Drupal\views\ViewExecutable::initDisplay().
     $view->initDisplay();
-    $this->assertTrue($view->displayHandlers instanceof DisplayCollection, 'The displayHandlers property has the right class.');
+    $this->assertTrue($view->displayHandlers instanceof DisplayPluginCollection, 'The displayHandlers property has the right class.');
     // Tests the classes of the instances.
     $this->assertTrue($view->displayHandlers->get('default') instanceof DefaultDisplay);
     $this->assertTrue($view->displayHandlers->get('page_1') instanceof Page);
diff -u b/core/modules/views/src/ViewExecutable.php b/core/modules/views/src/ViewExecutable.php
--- b/core/modules/views/src/ViewExecutable.php
+++ b/core/modules/views/src/ViewExecutable.php
@@ -202,7 +202,7 @@
    * An array containing Drupal\views\Plugin\views\display\DisplayPluginBase
    * objects.
    *
-   * @var \Drupal\views\DisplayCollection
+   * @var \Drupal\views\DisplayPluginCollection
    */
   public $displayHandlers;
 
@@ -619,7 +619,7 @@
     }
 
     // Initialize the display cache array.
-    $this->displayHandlers = new DisplayCollection($this, Views::pluginManager('display'));
+    $this->displayHandlers = new DisplayPluginCollection($this, Views::pluginManager('display'));
 
     $this->current_display = 'default';
     $this->display_handler = $this->displayHandlers->get('default');
diff -u b/core/modules/views_ui/src/Tests/DisplayFeedTest.php b/core/modules/views_ui/src/Tests/DisplayFeedTest.php
--- b/core/modules/views_ui/src/Tests/DisplayFeedTest.php
+++ b/core/modules/views_ui/src/Tests/DisplayFeedTest.php
@@ -49,7 +49,7 @@
     $this->drupalGet('admin/structure/views');
     // Verify that the page lists the $view_name view.
     // Regression test: ViewListBuilder::getDisplayPaths() did not properly
-    // check whether a DisplayCollection was returned in iterating over all
+    // check whether a DisplayPluginCollection was returned in iterating over all
     // displays.
     $this->assertText($view_name);
 

diff -u b/core/modules/views/src/DisplayCollection.php b/core/modules/views/src/DisplayPluginCollection.php
--- b/core/modules/views/src/DisplayCollection.php
+++ b/core/modules/views/src/DisplayPluginCollection.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\views\DisplayCollection.
+ * Contains \Drupal\views\DisplayPluginCollection.
  */
 
 namespace Drupal\views;
@@ -14,7 +14,7 @@
 /**
  * A class which wraps the displays of a view so you can lazy-initialize them.
  */
-class DisplayCollection extends DefaultLazyPluginCollection {
+class DisplayPluginCollection extends DefaultLazyPluginCollection {
 
   /**
    * Stores a reference to the view which has this displays attached.
@@ -29,7 +29,7 @@
   protected $pluginKey = 'display_plugin';
 
   /**
    * Constructs a DisplayCollection object.
    *
    * @param \Drupal\views\ViewExecutable
    *   The view which has this displays attached.
@@ -44,7 +44,7 @@
   }
 
   /**
    * Destructs a DisplayCollection object.
    */
   public function __destruct() {
     $this->clear();
@@ -29,7 +29,7 @@
 
   /**
-   * Constructs a DisplayCollection object.
+   * Constructs a DisplayPluginCollection object.
    *
    * @param \Drupal\views\ViewExecutable
@@ -44,7 +44,7 @@
 
   /**
-   * Destructs a DisplayCollection object.
+   * Destructs a DisplayPluginCollection object.
    */
   public function __destruct() {